@@ -124,7 +124,7 @@ impl Catcher for CatcherImpl {
         };
         res.headers_mut()
             .insert(header::CONTENT_TYPE, format.to_string().parse().unwrap());
-        res.write_body_bytes(&data);
+        res.write_body(&data).ok();
         true
     }
 }
